# Generated by Django 1.9.13 on 2018-01-06 13:01

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('leprikon', '0006_discount_periods'),
    ]

    operations = [
        migrations.AddField(
            model_name='subject',
            name='bill_print_setup',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='leprikon.PrintSetup', verbose_name='payment print setup'),
        ),
        migrations.AddField(
            model_name='subjecttype',
            name='bill_print_setup',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='leprikon.PrintSetup', verbose_name='payment print setup'),
        ),
    ]



from datetime import datetime

from django.http import JsonResponse
from django.shortcuts import get_object_or_404

from ..models.courses import Course
from ..views import leader_or_staff_required


@leader_or_staff_required
def course_registrations(request, course_id):
    qs = Course.objects.all()
    if not request.user.is_staff:
        qs = qs.filter(leaders=request.leader)
    course = get_object_or_404(qs, id=course_id)

    try:
        d = datetime.fromtimestamp(int(request.GET['date']))
    except:
        d = None

    return JsonResponse({
        'registrations': list({'value': r.id, 'label': str(r)} for r in course.get_approved_registrations(d)),
    })
